@@ -7,26 +7,39 @@
 var def = require('./def');
 
 function main (cxt) {
-    cxt.MEM = new ArrayBuffer(0x10000); // 3.3.3 Data space
+    var mem = new ArrayBuffer(0x10000); // 3.3.3 Data space
+    cxt.MEMi32 = new Int32Array(mem);
+
+    cxt.here = 0; // in bytes
+
+    def ('here', function () {
+        this.dpush(this.here);
+    }, cxt);
 
     def ('!', function () {
         var t = this.dpop();
         var n = this.dpop();
-        this.MEM[t] = n; // TODO 32-bit write?
+        this.MEMi32[t >> 2] = n; // TODO 32-bit write?
     }, cxt);
 
     def('2!', function () {
         var addr = this.dpop();
         var x2 = this.dpop();
         var x1 = this.dpop();
-        this.MEM[addr] = x1; // TODO 32-bit write?
+        this.MEMi32[addr >> 2] = x1; // TODO 32-bit write?
         addr += 4;
-        this.MEM[addr] = x2; // TODO 32-bit write?
+        this.MEMi32[addr >> 2] = x2; // TODO 32-bit write?
     }, cxt);
 
     def('@', function () {
         var t = this.dpop();
-        this.dpush(this.MEM[t]); // TODO 32-bit read?
+        this.dpush(this.MEMi32[t >> 2]); // TODO 32-bit read?
+    }, cxt);
+
+    def (',', function () {
+        var t = this.dpop();
+        this.MEMi32[this.here >> 2] = t;
+        this.here += 4;
     }, cxt);
 
 }
